@@ -1,33 +1,18 @@
-/* -------------------------------------------------------------
-   From KDE Tuberling
-   mailto:e.bischoff@noos.fr
- ------------------------------------------------------------- */
 /*
- * Copyright (C) 2001 Eric Bischoff
-   2004-2007 Anne-Marie Mahfouf <annma@kde.org>
+    SPDX-FileCopyrightText: KDE Tuberling <e.bischoff@noos.fr>
+    SPDX-FileCopyrightText: 2001 Eric Bischoff
+    SPDX-FileCopyrightText: 2004-2007 Anne-Marie Mahfouf <annma@kde.org>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "soundfactory.h"
 
+#include <KRandom>
 #include <QStandardPaths>
 
-#include <KMessageBox>
 #include <KLocalizedString>
-#include <KRandomSequence>
+#include <KMessageBox>
 #include <phonon/MediaObject>
 
 #include "klettres_debug.h"
@@ -185,13 +170,12 @@ bool SoundFactory::loadLanguage(QDomDocument &layoutDocument, const QString &cur
 void SoundFactory::setSoundSequence()
 {
     // Seed the random number generator
-    KRandomSequence randomSequence;
     randomList.clear();
     //get the number of sounds then shuffle it: each number will be taken once then the sequence will come back
     for (uint j = 0; j < sounds; j++) 
         randomList.append(j);
 
-    randomSequence.randomize(randomList);
+    KRandom::shuffle(randomList);
 }
 
 
